diff --git a/index.php b/index.php
index 7bff3a5..a867cbe 100644
--- a/index.php
+++ b/index.php
@@ -27,6 +27,8 @@ function navi() {
test.html
How to push data to included files
PHP Info
+ Non english route: german
+ Non english route: arabic
aTrailingSlashDoesNotMatter
aTrailingSlashDoesNotMatter/
theCaseDoesNotMatter
@@ -120,9 +122,16 @@ Route::add('/foo/bar/foo/bar', function() {
echo 'This is the second match (This route should only work in multi match mode)
';
});
// Route with non english letters
Route::add('/äöü', function() {
- echo 'Non english letters should work too
';
+ navi();
+ echo 'German example. Non english letters should work too
';
+});
+
+// Route with non english letters: arabic example
+Route::add('/الرقص-العربي', function() {
+ navi();
+ echo 'Arabic example. Non english letters should work too
';
});
// Trailing slash example
@@ -120,9 +122,16 @@ Route::add('/foo/bar/foo/bar', function() {
';
});
-// Route with non english letters
+// Route with non english letters: german example
Route::add('/äöü', function() {